GenotpFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • GenotpFlutterPlatform
Implementers

Constructors

GenotpFlutterPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildHotpUri({required String label, required String secretB32, String issuer = '', String algorithm = 'SHA1', int digits = 6, int counter = 0}) Future<String>
buildOtpAuthMigrationUri({required String accountsJson, int version = 1, int batchSize = 1, int batchIndex = 0, int batchId = 0}) Future<String>
buildTotpUri({required String label, required String secretB32, String issuer = '', String algorithm = 'SHA1', int digits = 6, int period = 30}) Future<String>
generateHotp({required String secretB32, required int counter, int algorithm = 0, int digits = 6}) Future<String>
generateSecret() Future<String>
generateTotp({required String secretB32, int algorithm = 0, int digits = 6, int period = 30}) Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseOtpAuthMigrationUri({required String uri}) Future<String>
toString() String
A string representation of this object.
inherited
verifyTotp({required String secretB32, required String code, int algorithm = 0, int digits = 6, int period = 30, int window = 1}) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance GenotpFlutterPlatform
getter/setter pair